@@ -77,14 +77,8 @@ this.latticeCells = this.acr.latticeCells;
 var isLatticeRange = (this.latticeCells[0] <= 555 && this.latticeCells[1] >= 555 && (this.latticeCells[2] == 0 || this.latticeCells[2] == 1 || this.latticeCells[2] == -1));
 this.doNormalize = this.latticeCells[0] != 0 && (!isLatticeRange || this.latticeCells[2] == 1);
 this.applySymmetryToBonds = this.acr.applySymmetryToBonds;
-this.doPackUnitCell = this.acr.doPackUnitCell;
-if (this.doPackUnitCell && this.applySymmetryToBonds) {
-var atoms = this.asc.atoms;
-var bonds = this.asc.bonds;
-for (var i = this.asc.bondCount; --i >= 0; ) {
-bonds[i].distance = atoms[bonds[i].atomIndex1].distance (atoms[bonds[i].atomIndex2]);
-}
-}this.doCentroidUnitCell = this.acr.doCentroidUnitCell;
+this.doPackUnitCell = this.acr.doPackUnitCell && !this.applySymmetryToBonds;
+this.doCentroidUnitCell = this.acr.doCentroidUnitCell;
 this.centroidPacked = this.acr.centroidPacked;
 this.filterSymop = this.acr.filterSymop;
 });
@@ -150,7 +144,7 @@ this.acr.addVibrations = false;
 }, "J.api.SymmetryInterface");
 Clazz.defineMethod (c$, "setSpaceGroupFrom", 
 function (readerSymmetry) {
-this.getSymmetry ().setSpaceGroupFrom (readerSymmetry);
+this.getSymmetry ().setSpaceGroupTo (readerSymmetry.getSpaceGroup ());
 }, "J.api.SymmetryInterface");
 Clazz.defineMethod (c$, "setAtomSetSpaceGroupName", 
  function (spaceGroupName) {
@@ -174,7 +168,7 @@ this.firstAtom = bsAtoms.nextSetBit (this.firstAtom);
 }this.rminx = this.rminy = this.rminz = 3.4028235E38;
 this.rmaxx = this.rmaxy = this.rmaxz = -3.4028235E38;
 var pt0 = null;
-if (this.acr.latticeType == null) this.acr.latticeType = this.symmetry.getLatticeType ();
+if (this.acr.latticeType == null) this.acr.latticeType = "" + this.symmetry.getLatticeType ();
 if (this.acr.isPrimitive) {
 this.asc.setCurrentModelInfo ("isprimitive", Boolean.TRUE);
 if (!"P".equals (this.acr.latticeType) || this.acr.primitiveToCrystal != null) {
@@ -212,7 +206,7 @@ pt0.setT (atoms[i]);
 this.symmetry.toCartesian (pt0, false);
 this.sym2.toFractional (pt0, false);
 if (this.acr.fixJavaFloat) JU.PT.fixPtFloats (pt0, 100000.0);
-if (!this.isWithinCell (this.ndims, pt0, 0, 1, 0, 1, 0, 1, this.packingError)) bsAtoms.clear (i);
+if (this.acr.noPack ? !this.removePacking (this.ndims, pt0, 0, 1, 0, 1, 0, 1, this.packingError) : !this.isWithinCell (this.ndims, pt0, 0, 1, 0, 1, 0, 1, this.packingError)) bsAtoms.clear (i);
 }
 return;
 }var offset = null;
@@ -225,11 +219,11 @@ var supercell = this.acr.strSupercell;
 var oabc = null;
 var isSuper = (supercell != null && supercell.indexOf (",") >= 0);
 if (isSuper) {
-oabc = this.symmetry.getV0abc (supercell);
-if (oabc != null) {
-this.minXYZ =  new JU.P3i ();
-this.maxXYZ = JU.P3i.new3 (maxX, maxY, maxZ);
-JU.SimpleUnitCell.setMinMaxLatticeParameters (dim, this.minXYZ, this.maxXYZ, kcode);
+var m =  new JU.M4 ();
+if (J.adapter.smarter.XtalSymmetry.mident == null) J.adapter.smarter.XtalSymmetry.mident =  new JU.M4 ();
+oabc = this.symmetry.getV0abc (supercell, m);
+if (oabc != null && !m.equals (J.adapter.smarter.XtalSymmetry.mident)) {
+this.setMinMax (dim, kcode, maxX, maxY, maxZ);
 pt0 = JU.P3.newP (oabc[0]);
 va = JU.P3.newP (oabc[1]);
 vb = JU.P3.newP (oabc[2]);
@@ -241,6 +235,7 @@ if (this.rminx == 3.4028235E38) {
 supercell = null;
 oabc = null;
 } else {
+this.asc.setGlobalBoolean (7);
 var doPack0 = this.doPackUnitCell;
 this.doPackUnitCell = doPack0;
 bsAtoms = this.updateBSAtoms ();
@@ -265,19 +260,33 @@ if (pt0 != null) atoms[i].sub (pt0);
 }
 this.asc.haveAnisou = false;
 this.asc.setCurrentModelInfo ("matUnitCellOrientation", null);
-}this.minXYZ =  new JU.P3i ();
-this.maxXYZ = JU.P3i.new3 (maxX, maxY, maxZ);
-JU.SimpleUnitCell.setMinMaxLatticeParameters (dim, this.minXYZ, this.maxXYZ, kcode);
+}this.setMinMax (dim, kcode, maxX, maxY, maxZ);
 if (oabc == null) {
 this.applyAllSymmetry (this.acr.ms, bsAtoms);
-return;
-}if (this.acr.forcePacked || this.doPackUnitCell) {
+if (!this.acr.noPack && (!this.applySymmetryToBonds || !this.acr.doPackUnitCell)) return;
+this.setMinMax (dim, kcode, maxX, maxY, maxZ);
+}if (this.acr.forcePacked || this.acr.doPackUnitCell || this.acr.noPack) {
+this.trimToUnitCell (iAtomFirst);
+}});
+Clazz.defineMethod (c$, "setMinMax", 
+ function (dim, kcode, maxX, maxY, maxZ) {
+this.minXYZ =  new JU.P3i ();
+this.maxXYZ = JU.P3i.new3 (maxX, maxY, maxZ);
+JU.SimpleUnitCell.setMinMaxLatticeParameters (dim, this.minXYZ, this.maxXYZ, kcode);
+}, "~N,~N,~N,~N,~N");
+Clazz.defineMethod (c$, "trimToUnitCell", 
+ function (iAtomFirst) {
 var atoms = this.asc.atoms;
 var bs = this.updateBSAtoms ();
+if (this.acr.noPack) {
+for (var i = bs.nextSetBit (iAtomFirst); i >= 0; i = bs.nextSetBit (i + 1)) {
+if (!this.removePacking (this.ndims, atoms[i], this.minXYZ.x, this.maxXYZ.x, this.minXYZ.y, this.maxXYZ.y, this.minXYZ.z, this.maxXYZ.z, this.packingError)) bs.clear (i);
+}
+} else {
 for (var i = bs.nextSetBit (iAtomFirst); i >= 0; i = bs.nextSetBit (i + 1)) {
 if (!this.isWithinCell (this.ndims, atoms[i], this.minXYZ.x, this.maxXYZ.x, this.minXYZ.y, this.maxXYZ.y, this.minXYZ.z, this.maxXYZ.z, this.packingError)) bs.clear (i);
 }
-}});
+}}, "~N");
 Clazz.defineMethod (c$, "updateBSAtoms", 
  function () {
 var bs = this.asc.bsAtoms;
@@ -340,22 +349,28 @@ Clazz.defineMethod (c$, "isWithinCell",
 function (ndims, pt, minX, maxX, minY, maxY, minZ, maxZ, slop) {
 return (pt.x > minX - slop && pt.x < maxX + slop && (ndims < 2 || pt.y > minY - slop && pt.y < maxY + slop) && (ndims < 3 || pt.z > minZ - slop && pt.z < maxZ + slop));
 }, "~N,JU.P3,~N,~N,~N,~N,~N,~N,~N");
+Clazz.defineMethod (c$, "removePacking", 
+function (ndims, pt, minX, maxX, minY, maxY, minZ, maxZ, slop) {
+return (pt.x > minX - slop && pt.x < maxX - slop && (ndims < 2 || pt.y > minY - slop && pt.y < maxY - slop) && (ndims < 3 || pt.z > minZ - slop && pt.z < maxZ - slop));
+}, "~N,JU.P3,~N,~N,~N,~N,~N,~N,~N");
 Clazz.defineMethod (c$, "applyAllSymmetry", 
  function (ms, bsAtoms) {
 if (this.asc.ac == 0 || bsAtoms != null && bsAtoms.isEmpty ()) return;
 var n = this.noSymmetryCount = this.asc.baseSymmetryAtomCount > 0 ? this.asc.baseSymmetryAtomCount : bsAtoms == null ? this.asc.getLastAtomSetAtomCount () : this.asc.ac - bsAtoms.nextSetBit (this.asc.getLastAtomSetAtomIndex ());
 this.asc.setTensors ();
+this.applySymmetryToBonds = this.acr.applySymmetryToBonds;
+this.doPackUnitCell = this.acr.doPackUnitCell && !this.applySymmetryToBonds;
 this.bondCount0 = this.asc.bondCount;
+this.ndims = Clazz.floatToInt (this.symmetry.getUnitCellInfoType (6));
 this.finalizeSymmetry (this.symmetry);
 var operationCount = this.symmetry.getSpaceGroupOperationCount ();
 var excludedOps = (this.acr.thisBiomolecule == null ? null :  new JU.BS ());
 if (excludedOps != null) this.asc.checkSpecial = true;
-this.ndims = Clazz.floatToInt (this.symmetry.getUnitCellInfoType (6));
 JU.SimpleUnitCell.setMinMaxLatticeParameters (this.ndims, this.minXYZ, this.maxXYZ, 0);
 this.latticeOp = this.symmetry.getLatticeOp ();
 this.latticeOnly = (this.asc.checkLatticeOnly && this.latticeOp >= 0);
 if (this.doCentroidUnitCell) this.asc.setInfo ("centroidMinMax",  Clazz.newIntArray (-1, [this.minXYZ.x, this.minXYZ.y, this.minXYZ.z, this.maxXYZ.x, this.maxXYZ.y, this.maxXYZ.z, (this.centroidPacked ? 1 : 0)]));
-if (this.doCentroidUnitCell || this.doPackUnitCell || this.symmetryRange != 0 && this.maxXYZ.x - this.minXYZ.x == 1 && this.maxXYZ.y - this.minXYZ.y == 1 && this.maxXYZ.z - this.minXYZ.z == 1) {
+if (this.doCentroidUnitCell || this.acr.doPackUnitCell || this.symmetryRange != 0 && this.maxXYZ.x - this.minXYZ.x == 1 && this.maxXYZ.y - this.minXYZ.y == 1 && this.maxXYZ.z - this.minXYZ.z == 1) {
 this.minXYZ0 = JU.P3.new3 (this.minXYZ.x, this.minXYZ.y, this.minXYZ.z);
 this.maxXYZ0 = JU.P3.new3 (this.maxXYZ.x, this.maxXYZ.y, this.maxXYZ.z);
 if (ms != null) {
@@ -381,7 +396,6 @@ var atoms = this.asc.atoms;
 for (var i = 0; i < n; i++) atoms[this.firstAtom + i].bsSymmetry = JU.BS.newN (operationCount * (nCells + 1));
 
 var pt = 0;
-var unitCells =  Clazz.newIntArray (nCells, 0);
 this.unitCellTranslations =  new Array (nCells);
 var iCell = 0;
 var cell555Count = 0;
@@ -392,51 +406,54 @@ var checkRange111 = (this.symmetryRange > 0);
 if (checkCartesianRange) {
 this.rminx = this.rminy = this.rminz = 3.4028235E38;
 this.rmaxx = this.rmaxy = this.rmaxz = -3.4028235E38;
-}var thisSymmetry = this.symmetry;
-var lastSymmetry = thisSymmetry;
+}var sym = this.symmetry;
+var lastSymmetry = sym;
 this.checkAll = (this.latticeOnly || this.asc.atomSetCount == 1 && this.asc.checkSpecial && this.latticeOp >= 0);
-var pttemp = null;
-var op = thisSymmetry.getSpaceGroupOperation (0);
-if (this.doPackUnitCell) {
-pttemp =  new JU.P3 ();
-this.ptOffset.set (0, 0, 0);
-}var atomMap = (this.bondCount0 > this.asc.bondIndex0 && this.applySymmetryToBonds ?  Clazz.newIntArray (n, 0) : null);
 var lstNCS = this.acr.lstNCS;
 if (lstNCS != null && lstNCS.get (0).m33 == 0) {
-var nOp = thisSymmetry.getSpaceGroupOperationCount ();
+var nOp = sym.getSpaceGroupOperationCount ();
 var nn = lstNCS.size ();
 for (var i = nn; --i >= 0; ) {
 var m = lstNCS.get (i);
 m.m33 = 1;
-thisSymmetry.toFractionalM (m);
+sym.toFractionalM (m);
 }
 for (var i = 1; i < nOp; i++) {
-var m1 = thisSymmetry.getSpaceGroupOperation (i);
+var m1 = sym.getSpaceGroupOperation (i);
 for (var j = 0; j < nn; j++) {
 var m = JU.M4.newM4 (lstNCS.get (j));
 m.mul2 (m1, m);
-if (this.doNormalize) JS.SymmetryOperation.setOffset (m, atoms, this.firstAtom, this.noSymmetryCount);
+if (this.doNormalize && this.noSymmetryCount > 0) JS.SymmetryOperation.normalizeOperationToCentroid (3, m, atoms, this.firstAtom, this.noSymmetryCount);
 lstNCS.addLast (m);
 }
 }
-}for (var tx = this.minXYZ.x; tx < this.maxXYZ.x; tx++) for (var ty = this.minXYZ.y; ty < this.maxXYZ.y; ty++) for (var tz = this.minXYZ.z; tz < this.maxXYZ.z; tz++) {
+}var pttemp = null;
+var op = sym.getSpaceGroupOperation (0);
+if (this.doPackUnitCell) {
+pttemp =  new JU.P3 ();
+this.ptOffset.set (0, 0, 0);
+}var atomMap = (this.bondCount0 > this.asc.bondIndex0 && this.applySymmetryToBonds ?  Clazz.newIntArray (n, 0) : null);
+var unitCells =  Clazz.newIntArray (nCells, 0);
+for (var tx = this.minXYZ.x; tx < this.maxXYZ.x; tx++) {
+for (var ty = this.minXYZ.y; ty < this.maxXYZ.y; ty++) {
+for (var tz = this.minXYZ.z; tz < this.maxXYZ.z; tz++) {
 this.unitCellTranslations[iCell] = JU.V3.new3 (tx, ty, tz);
 unitCells[iCell++] = 555 + tx * 100 + ty * 10 + tz;
 if (tx != 0 || ty != 0 || tz != 0 || cartesians.length == 0) continue;
 for (pt = 0; pt < n; pt++) {
 var atom = atoms[this.firstAtom + pt];
 if (ms != null) {
-thisSymmetry = ms.getAtomSymmetry (atom, this.symmetry);
-if (thisSymmetry !== lastSymmetry) {
-if (thisSymmetry.getSpaceGroupOperationCount () == 0) this.finalizeSymmetry (lastSymmetry = thisSymmetry);
-op = thisSymmetry.getSpaceGroupOperation (0);
+sym = ms.getAtomSymmetry (atom, this.symmetry);
+if (sym !== lastSymmetry) {
+if (sym.getSpaceGroupOperationCount () == 0) this.finalizeSymmetry (lastSymmetry = sym);
+op = sym.getSpaceGroupOperation (0);
 }}var c = JU.P3.newP (atom);
 op.rotTrans (c);
-thisSymmetry.toCartesian (c, false);
+sym.toCartesian (c, false);
 if (this.doPackUnitCell) {
-thisSymmetry.toUnitCell (c, this.ptOffset);
+sym.toUnitCellRnd (c, this.ptOffset);
 pttemp.setT (c);
-thisSymmetry.toFractional (pttemp, false);
+sym.toFractional (pttemp, false);
 if (this.acr.fixJavaFloat) JU.PT.fixPtFloats (pttemp, 100000.0);
 if (bsAtoms == null) atom.setT (pttemp);
  else if (atom.distance (pttemp) < 0.0001) bsAtoms.set (atom.index);
@@ -458,8 +475,8 @@ this.rmaxy += absRange;
 this.rmaxz += absRange;
 }cell555Count = pt = this.symmetryAddAtoms (0, 0, 0, 0, pt, iCell * operationCount, cartesians, ms, excludedOps, atomMap);
 }
-
-
+}
+}
 if (checkRange111) {
 this.rminx -= absRange;
 this.rminy -= absRange;
@@ -478,7 +495,7 @@ if (iCell * n == this.asc.ac - this.firstAtom) this.duplicateAtomProperties (iCe
 this.setSymmetryOps ();
 this.asc.setCurrentModelInfo ("presymmetryAtomIndex", Integer.$valueOf (this.firstAtom));
 this.asc.setCurrentModelInfo ("presymmetryAtomCount", Integer.$valueOf (n));
-this.asc.setCurrentModelInfo ("latticeDesignation", thisSymmetry.getLatticeDesignation ());
+this.asc.setCurrentModelInfo ("latticeDesignation", sym.getLatticeDesignation ());
 this.asc.setCurrentModelInfo ("unitCellRange", unitCells);
 this.asc.setCurrentModelInfo ("unitCellTranslations", this.unitCellTranslations);
 this.baseUnitCell = this.unitCellParams;
@@ -506,10 +523,10 @@ var checkDistances = (checkSpecial || checkSymmetryRange);
 var checkOps = (excludedOps != null);
 var addCartesian = (checkSpecial || checkSymmetryMinMax);
 var bsAtoms = (this.acr.isMolecular ? null : this.asc.bsAtoms);
-var symmetry = this.symmetry;
+var sym = this.symmetry;
 if (checkRangeNoSymmetry) baseCount = this.noSymmetryCount;
 var atomMax = this.firstAtom + this.noSymmetryCount;
-var ptAtom =  new JU.P3 ();
+var pttemp =  new JU.P3 ();
 var code = null;
 var d0 = (checkOps ? 0.01 : 0.0001);
 var subSystemId = '\u0000';
@@ -517,7 +534,7 @@ var j00 = (bsAtoms == null ? this.firstAtom : bsAtoms.nextSetBit (this.firstAtom
 out : for (var iSym = 0; iSym < nOperations; iSym++) {
 if (isBaseCell && iSym == 0 || this.latticeOnly && iSym > 0 && (iSym % this.latticeOp) != 0 || excludedOps != null && excludedOps.get (iSym)) continue;
 var pt0 = this.firstAtom + (checkSpecial || excludedOps != null ? pt : checkRange111 ? baseCount : 0);
-var spinOp = (iSym >= nOp ? 0 : this.asc.vibScale == 0 ? symmetry.getSpinOp (iSym) : this.asc.vibScale);
+var spinOp = (iSym >= nOp ? 0 : this.asc.vibScale == 0 ? sym.getSpinOp (iSym) : this.asc.vibScale);
 var i0 = Math.max (this.firstAtom, (bsAtoms == null ? 0 : bsAtoms.nextSetBit (0)));
 var checkDistance = checkDistances;
 var spt = (iSym >= nOp ? Clazz.doubleToInt ((iSym - nOp) / nNCS) : iSym);
@@ -526,24 +543,24 @@ for (var i = i0; i < atomMax; i++) {
 var a = this.asc.atoms[i];
 if (a.ignoreSymmetry || bsAtoms != null && !bsAtoms.get (i)) continue;
 if (ms == null) {
-symmetry.newSpaceGroupPoint (iSym, a, ptAtom, transX, transY, transZ, (iSym >= nOp ? lstNCS.get (iSym - nOp) : null));
+sym.newSpaceGroupPoint (a, iSym, (iSym >= nOp ? lstNCS.get (iSym - nOp) : null), transX, transY, transZ, pttemp);
 } else {
-symmetry = ms.getAtomSymmetry (a, this.symmetry);
-symmetry.newSpaceGroupPoint (iSym, a, ptAtom, transX, transY, transZ, null);
-code = symmetry.getSpaceGroupOperationCode (iSym);
+sym = ms.getAtomSymmetry (a, this.symmetry);
+sym.newSpaceGroupPoint (a, iSym, null, transX, transY, transZ, pttemp);
+code = sym.getSpaceGroupOperationCode (iSym);
 if (code != null) {
 subSystemId = code.charAt (0);
-symmetry = ms.getSymmetryFromCode (code);
-if (symmetry.getSpaceGroupOperationCount () == 0) this.finalizeSymmetry (symmetry);
-}}if (this.acr.fixJavaFloat) JU.PT.fixPtFloats (ptAtom, 100000.0);
-var c = JU.P3.newP (ptAtom);
-symmetry.toCartesian (c, false);
+sym = ms.getSymmetryFromCode (code);
+if (sym.getSpaceGroupOperationCount () == 0) this.finalizeSymmetry (sym);
+}}if (this.acr.fixJavaFloat) JU.PT.fixPtFloats (pttemp, 100000.0);
+var c = JU.P3.newP (pttemp);
+sym.toCartesian (c, false);
 if (this.doPackUnitCell) {
-symmetry.toUnitCell (c, this.ptOffset);
-ptAtom.setT (c);
-symmetry.toFractional (ptAtom, false);
-if (this.acr.fixJavaFloat) JU.PT.fixPtFloats (ptAtom, 100000.0);
-if (!this.isWithinCell (this.ndims, ptAtom, this.minXYZ0.x, this.maxXYZ0.x, this.minXYZ0.y, this.maxXYZ0.y, this.minXYZ0.z, this.maxXYZ0.z, this.packingError)) continue;
+sym.toUnitCellRnd (c, this.ptOffset);
+pttemp.setT (c);
+sym.toFractional (pttemp, false);
+if (this.acr.fixJavaFloat) JU.PT.fixPtFloats (pttemp, 100000.0);
+if (!this.isWithinCell (this.ndims, pttemp, this.minXYZ0.x, this.maxXYZ0.x, this.minXYZ0.y, this.maxXYZ0.y, this.minXYZ0.z, this.maxXYZ0.z, this.packingError)) continue;
 }if (checkSymmetryMinMax) this.setSymmetryMinMax (c);
 var special = null;
 if (checkDistance) {
@@ -576,11 +593,10 @@ special.bsSymmetry.set (cpt);
 special.bsSymmetry.set (spt);
 } else {
 if (addBonds) atomMap[atomSite] = this.asc.ac;
-var atom1 = this.asc.newCloneAtom (a);
-atom1.setT (ptAtom);
+var atom1 = a.copyTo (pttemp, this.asc);
 if (this.asc.bsAtoms != null) this.asc.bsAtoms.set (atom1.index);
 if (spinOp != 0 && atom1.vib != null) {
-symmetry.getSpaceGroupOperation (iSym).rotate (atom1.vib);
+sym.getSpaceGroupOperation (iSym).rotate (atom1.vib);
 atom1.vib.scale (spinOp);
 }atom1.atomSite = atomSite;
 if (code != null) atom1.altLoc = subSystemId;
@@ -594,7 +610,7 @@ for (var j = tensors.size (); --j >= 0; ) {
 var t = tensors.get (j);
 if (t == null) continue;
 if (nOp == 1) atom1.addTensor (t.copyTensor (), null, false);
- else this.addRotatedTensor (atom1, t, iSym, false, symmetry);
+ else this.addRotatedTensor (atom1, t, iSym, false, sym);
 }
 }}}
 if (addBonds) {
@@ -605,17 +621,16 @@ for (var bondNum = this.asc.bondIndex0; bondNum < this.bondCount0; bondNum++) {
 var bond = bonds[bondNum];
 var atom1 = atoms[bond.atomIndex1];
 var atom2 = atoms[bond.atomIndex2];
-if (atom1 == null || atom2 == null) continue;
+if (atom1 == null || atom2 == null || atom2.atomSetIndex < atom1.atomSetIndex) continue;
 var ia1 = atomMap[atom1.atomSite];
 var ia2 = atomMap[atom2.atomSite];
-var d = 0;
 if (ia1 > ia2) {
 var i = ia1;
 ia1 = ia2;
 ia2 = i;
 }if (ia1 != ia2 && (ia1 >= atomMax || ia2 >= atomMax) && this.bondsFound.indexOf (key = "-" + ia1 + "," + ia2) < 0) {
 this.bondsFound.append (key);
-this.asc.addNewBondWithOrder (ia1, ia2, bond.order).distance = d;
+this.asc.addNewBondWithOrder (ia1, ia2, bond.order);
 }}
 }}
 return pt;
@@ -642,7 +657,7 @@ for (var i = nTimes; --i >= 0; ) System.arraycopy (f, 0, fnew, i * f.length, f.l
 Clazz.defineMethod (c$, "finalizeSymmetry", 
  function (symmetry) {
 var name = this.asc.getAtomSetAuxiliaryInfoValue (-1, "spaceGroup");
-symmetry.setFinalOperations (name, this.asc.atoms, this.firstAtom, this.noSymmetryCount, this.doNormalize, this.filterSymop);
+symmetry.setFinalOperations (this.ndims, name, this.asc.atoms, this.firstAtom, this.noSymmetryCount, this.doNormalize, this.filterSymop);
 if (this.filterSymop != null || name == null || name.equals ("unspecified!")) this.setAtomSetSpaceGroupName (symmetry.getSpaceGroupName ());
 }, "J.api.SymmetryInterface");
 Clazz.defineMethod (c$, "setSymmetryOps", 
@@ -666,23 +681,28 @@ return (this.maxXYZ0 == null ? JU.V3.new3 (this.maxXYZ.x - this.minXYZ.x, this.m
 Clazz.defineMethod (c$, "applySymmetryBio", 
 function (thisBiomolecule, applySymmetryToBonds, filter) {
 var biomts = thisBiomolecule.get ("biomts");
-if (biomts.size () < 2) return;
-this.acr.lstNCS = null;
+var len = biomts.size ();
+if (J.adapter.smarter.XtalSymmetry.mident == null) {
+J.adapter.smarter.XtalSymmetry.mident =  new JU.M4 ();
+J.adapter.smarter.XtalSymmetry.mident.setIdentity ();
+}this.acr.lstNCS = null;
 this.setLatticeCells ();
 var lc = (this.latticeCells != null && this.latticeCells[0] != 0 ?  Clazz.newIntArray (3, 0) : null);
 if (lc != null) for (var i = 0; i < 3; i++) lc[i] = this.latticeCells[i];
 
 this.latticeCells = null;
-var particleMode = (filter.indexOf ("BYCHAIN") >= 0 ? 1 : filter.indexOf ("BYSYMOP") >= 0 ? 2 : 0);
+var bmChains = this.acr.getFilterWithCase ("BMCHAINS");
+var fixBMChains = (bmChains == null ? -1 : bmChains.length < 2 ? 0 : JU.PT.parseInt (bmChains.substring (1)));
+if (fixBMChains == -2147483648) {
+fixBMChains = -(bmChains.charAt (1)).charCodeAt (0);
+}var particleMode = (filter.indexOf ("BYCHAIN") >= 0 ? 1 : filter.indexOf ("BYSYMOP") >= 0 ? 2 : 0);
 this.doNormalize = false;
 var biomtchains = thisBiomolecule.get ("chains");
-if (biomtchains.get (0).equals (biomtchains.get (1))) biomtchains = null;
 this.symmetry = null;
 this.getSymmetry ().setSpaceGroup (this.doNormalize);
 this.addSpaceGroupOperation ("x,y,z", false);
 var name = thisBiomolecule.get ("name");
 this.setAtomSetSpaceGroupName (this.acr.sgName = name);
-var len = biomts.size ();
 this.applySymmetryToBonds = applySymmetryToBonds;
 this.bondCount0 = this.asc.bondCount;
 this.firstAtom = this.asc.getLastAtomSetAtomIndex ();
@@ -742,34 +762,48 @@ var assemblyIdAtoms = thisBiomolecule.get ("asemblyIdAtoms");
 if (filter.indexOf ("#<") >= 0) {
 len = Math.min (len, JU.PT.parseInt (filter.substring (filter.indexOf ("#<") + 2)) - 1);
 filter = JU.PT.rep (filter, "#<", "_<");
-}for (var iAtom = this.firstAtom; iAtom < atomMax; iAtom++) atoms[iAtom].bsSymmetry = JU.BSUtil.newAndSetBit (0);
-
+}var maxChain = 0;
+for (var iAtom = this.firstAtom; iAtom < atomMax; iAtom++) {
+atoms[iAtom].bsSymmetry =  new JU.BS ();
+var chainID = atoms[iAtom].chainID;
+if (chainID > maxChain) maxChain = chainID;
+}
 var bsAtoms = this.asc.bsAtoms;
 var atomMap = (addBonds ?  Clazz.newIntArray (this.asc.ac, 0) : null);
-for (var i = (biomtchains == null ? 1 : 0); i < len; i++) {
+for (var imt = (biomtchains == null ? 1 : 0); imt < len; imt++) {
 if (filter.indexOf ("!#") >= 0) {
-if (filter.indexOf ("!#" + (i + 1) + ";") >= 0) continue;
-} else if (filter.indexOf ("#") >= 0 && filter.indexOf ("#" + (i + 1) + ";") < 0) {
+if (filter.indexOf ("!#" + (imt + 1) + ";") >= 0) continue;
+} else if (filter.indexOf ("#") >= 0 && filter.indexOf ("#" + (imt + 1) + ";") < 0) {
 continue;
-}var mat = biomts.get (i);
-var chains = (biomtchains == null ? null : biomtchains.get (i));
+}var mat = biomts.get (imt);
+var notIdentity = !mat.equals (J.adapter.smarter.XtalSymmetry.mident);
+var chains = (biomtchains == null ? null : biomtchains.get (imt));
 if (chains != null && assemblyIdAtoms != null) {
 bsAtoms =  new JU.BS ();
 for (var e, $e = assemblyIdAtoms.entrySet ().iterator (); $e.hasNext () && ((e = $e.next ()) || true);) if (chains.indexOf (":" + e.getKey () + ";") >= 0) bsAtoms.or (e.getValue ());
 
 if (this.asc.bsAtoms != null) bsAtoms.and (this.asc.bsAtoms);
 chains = null;
-}for (var iAtom = this.firstAtom; iAtom < atomMax; iAtom++) {
-if (bsAtoms != null && !bsAtoms.get (iAtom) || chains != null && chains.indexOf (":" + this.acr.vwr.getChainIDStr (atoms[iAtom].chainID) + ";") < 0) continue;
+}var lastID = -1;
+var id;
+var skipping = false;
+for (var iAtom = this.firstAtom; iAtom < atomMax; iAtom++) {
+if (bsAtoms != null) {
+skipping = !bsAtoms.get (iAtom);
+} else if (chains != null && (id = atoms[iAtom].chainID) != lastID) {
+skipping = (chains.indexOf (":" + this.acr.vwr.getChainIDStr (lastID = id) + ";") < 0);
+}if (skipping) continue;
 try {
 var atomSite = atoms[iAtom].atomSite;
 var atom1;
 if (addBonds) atomMap[atomSite] = this.asc.ac;
 atom1 = this.asc.newCloneAtom (atoms[iAtom]);
+atom1.bondingRadius = imt;
+this.asc.atomSymbolicMap.put ("" + atom1.atomSerial, atom1);
 if (this.asc.bsAtoms != null) this.asc.bsAtoms.set (atom1.index);
 atom1.atomSite = atomSite;
-mat.rotTrans (atom1);
-atom1.bsSymmetry = JU.BSUtil.newAndSetBit (i);
+if (notIdentity) mat.rotTrans (atom1);
+atom1.bsSymmetry = JU.BSUtil.newAndSetBit (imt);
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
 this.asc.errorMessage = "appendAtomCollection error: " + e;
@@ -778,8 +812,7 @@ throw e;
 }
 }
 }
-if (i > 0) {
-this.symmetry.addBioMoleculeOperation (mat, false);
+if (notIdentity) this.symmetry.addBioMoleculeOperation (mat, false);
 if (addBonds) {
 for (var bondNum = this.asc.bondIndex0; bondNum < this.bondCount0; bondNum++) {
 var bond = this.asc.bonds[bondNum];
@@ -787,10 +820,81 @@ var iAtom1 = atomMap[atoms[bond.atomIndex1].atomSite];
 var iAtom2 = atomMap[atoms[bond.atomIndex2].atomSite];
 this.asc.addNewBondWithOrder (iAtom1, iAtom2, bond.order);
 }
-}}}
+}}
 if (biomtchains != null) {
 if (this.asc.bsAtoms == null) this.asc.bsAtoms = JU.BSUtil.newBitSet2 (0, this.asc.ac);
 this.asc.bsAtoms.clearBits (this.firstAtom, atomMax);
+if (particleMode == 0) {
+if (fixBMChains != -1) {
+var assignABC = (fixBMChains != 0);
+var bsChains = (assignABC ?  new JU.BS () : null);
+atoms = this.asc.atoms;
+var firstNew = 0;
+if (assignABC) {
+firstNew = (fixBMChains < 0 ? Math.max (-fixBMChains, maxChain + 1) : Math.max (maxChain + fixBMChains, 65));
+bsChains.setBits (0, firstNew - 1);
+bsChains.setBits (91, 97);
+bsChains.setBits (123, 200);
+}var bsAll = (this.asc.structureCount == 1 ? this.asc.structures[0].bsAll : null);
+var chainMap =  new java.util.Hashtable ();
+var knownMap =  new java.util.Hashtable ();
+var knownAtomMap = (bsAll == null ? null :  new java.util.Hashtable ());
+var lastKnownAtom = null;
+for (var i = atomMax, n = this.asc.ac; i < n; i++) {
+var ic = atoms[i].chainID;
+var isym = atoms[i].bsSymmetry.nextSetBit (0);
+var ch0 = this.acr.vwr.getChainIDStr (ic);
+var ch = (isym == 0 ? ch0 : ch0 + isym);
+var known = chainMap.get (ch);
+if (known == null) {
+if (assignABC && isym != 0) {
+var pt = (firstNew < 200 ? bsChains.nextClearBit (firstNew) : 200);
+if (pt < 200) {
+bsChains.set (pt);
+known = Integer.$valueOf (this.acr.vwr.getChainID ("" + String.fromCharCode (pt), true));
+firstNew = pt;
+} else {
+}}if (known == null) known = Integer.$valueOf (this.acr.vwr.getChainID (ch, true));
+if (ch !== ch0) {
+knownMap.put (known, Integer.$valueOf (ic));
+if (bsAll != null) {
+if (lastKnownAtom != null) lastKnownAtom[1] = i;
+knownAtomMap.put (known, lastKnownAtom =  Clazz.newIntArray (-1, [i, n]));
+}}chainMap.put (ch, known);
+}atoms[i].chainID = known.intValue ();
+}
+if (this.asc.structureCount > 0) {
+var strucs = this.asc.structures;
+var nStruc = this.asc.structureCount;
+for (var e, $e = knownMap.entrySet ().iterator (); $e.hasNext () && ((e = $e.next ()) || true);) {
+var known = e.getKey ();
+var ch1 = known.intValue ();
+var ch0 = e.getValue ().intValue ();
+for (var i = 0; i < nStruc; i++) {
+var s = strucs[i];
+if (s.bsAll != null) {
+} else if (s.startChainID == s.endChainID) {
+if (s.startChainID == ch0) {
+var s1 = s.clone ();
+s1.startChainID = s1.endChainID = ch1;
+this.asc.addStructure (s1);
+}} else {
+System.err.println ("XtalSymmetry not processing biomt chain structure " + this.acr.vwr.getChainIDStr (ch0) + " to " + this.acr.vwr.getChainIDStr (ch1));
+}}
+}
+}}var vConnect = this.asc.getAtomSetAuxiliaryInfoValue (-1, "PDB_CONECT_bonds");
+if (!addBonds && vConnect != null) {
+for (var i = vConnect.size (); --i >= 0; ) {
+var bond = vConnect.get (i);
+var a = this.asc.getAtomFromName ("" + bond[0]);
+var b = this.asc.getAtomFromName ("" + bond[1]);
+if (a != null && b != null && a.bondingRadius != b.bondingRadius && (bsAtoms == null || bsAtoms.get (a.index) && bsAtoms.get (b.index)) && a.distanceSquared (b) > 25.0) {
+vConnect.removeItemAt (i);
+System.out.println ("long interchain bond removed for @" + a.atomSerial + "-@" + b.atomSerial);
+}}
+}}for (var i = atomMax, n = this.asc.ac; i < n; i++) {
+this.asc.atoms[i].bondingRadius = NaN;
+}
 }this.noSymmetryCount = atomMax - this.firstAtom;
 this.asc.setCurrentModelInfo ("presymmetryAtomIndex", Integer.$valueOf (this.firstAtom));
 this.asc.setCurrentModelInfo ("presymmetryAtomCount", Integer.$valueOf (this.noSymmetryCount));
@@ -871,5 +975,7 @@ this.baseUnitCell[24] = Math.max (1, Clazz.floatToInt (ptSupercell.z));
 Clazz.defineStatics (c$,
 "PARTICLE_NONE", 0,
 "PARTICLE_CHAIN", 1,
-"PARTICLE_SYMOP", 2);
+"PARTICLE_SYMOP", 2,
+"MAX_INTERCHAIN_BOND_2", 25,
+"mident", null);
 });
