@@ -589,13 +589,14 @@ bs.andNot (bsA);
 if (bs.nextSetBit (0) >= 0) this.vwr.deleteAtoms (bs, false);
 bs = this.vwr.getModelUndeletedAtomsBitSet (atom.mi);
 bs.andNot (this.vwr.ms.getAtomBitsMDa (1612709900, null,  new JU.BS ()));
-this.vwr.ms.makeConnections2 (0.1, 1.8, 1, 1073741904, bsA, bs, null, false, false, 0);
+this.vwr.ms.makeConnections2 (0.1, 1.8, 1, 1073741904, bsA, bs, null, false, false, 0, null);
 }if (this.addXtalHydrogens) this.vwr.addHydrogens (bsA, 1);
 return atomicNumber;
 }, "~N,~S,~B,~B,~B,JU.BS");
 Clazz.defineMethod (c$, "cmdAssignSpaceGroup", 
 function (bs, name, mi) {
 var isP1 = (name.equalsIgnoreCase ("P1") || name.equals ("1"));
+var isDefined = (!isP1 && name.length > 0);
 this.clearAtomConstraints ();
 try {
 if (bs != null && bs.isEmpty ()) return "";
@@ -617,21 +618,23 @@ m.z = 0;
 var oabc;
 var ita;
 var basis;
-var sg = (noAtoms || isP1 ? null : this.vwr.findSpaceGroup (bsAtoms, null, false));
-if (sg == null) {
+var sg = null;
+var sgInfo = (noAtoms || isP1 ? null : this.vwr.findSpaceGroup (isDefined ? null : bsAtoms, isDefined ? name : null, sym.getUnitCellParams (), false, true));
+if (sgInfo == null) {
 name = "P1";
 supercell = JU.P3.new3 (1, 1, 1);
 oabc = sym.getUnitCellVectors ();
 ita = "1";
 basis = null;
 } else {
-supercell = sg.get ("supercell");
-oabc = sg.get ("unitcell");
-name = sg.get ("name");
-ita = sg.get ("itaFull");
-basis = sg.get ("basis");
+supercell = sgInfo.get ("supercell");
+oabc = sgInfo.get ("unitcell");
+name = sgInfo.get ("name");
+ita = sgInfo.get ("itaFull");
+basis = sgInfo.get ("basis");
+sg = sgInfo.remove ("sg");
 }sym.getUnitCell (oabc, false, null);
-sym.setSpaceGroupTo (ita);
+sym.setSpaceGroupTo (sg == null ? ita : sg);
 sym.setSpaceGroupName (name);
 if (basis == null) basis = sym.removeDuplicates (this.vwr.ms, bsAtoms, true);
 this.vwr.ms.setSpaceGroup (mi, sym, basis);
@@ -1197,7 +1200,7 @@ var list =  new JU.Lst ();
 var atomicNo = -1;
 var site = 0;
 var pf = null;
-if (pts.length == 1) {
+if (pts != null && pts.length == 1) {
 pf = JU.P3.newP (pts[0]);
 uc.toFractional (pf, true);
 }for (var i = bsM.nextSetBit (0); i >= 0; i = bsM.nextSetBit (i + 1)) {
@@ -1205,7 +1208,7 @@ var p = JU.P3.newP (this.vwr.ms.at[i]);
 uc.toFractional (p, true);
 if (pf != null && pf.distanceSquared (p) < 1.96E-6) {
 site = this.vwr.ms.at[i].getAtomSite ();
-if (type == null) type = this.vwr.ms.at[i].getElementSymbolIso (true);
+if (type == null || pts == null) type = this.vwr.ms.at[i].getElementSymbolIso (true);
 }list.addLast (p);
 }
 var nIgnored = list.size ();
