@@ -88,11 +88,14 @@ return;
 this.renderXyPoint ();
 }}var tension = 5;
 switch (this.drawType) {
+case J.shapespecial.Draw.EnumDrawType.CYLINDER:
+this.allowDashed = false;
 default:
 this.render2b (false);
 return;
 case J.shapespecial.Draw.EnumDrawType.CIRCULARPLANE:
 if (this.dmesh.scale > 0) this.width *= this.dmesh.scale;
+this.allowDashed = false;
 this.render2b (false);
 return;
 case J.shapespecial.Draw.EnumDrawType.CIRCLE:
