@@ -233,9 +233,6 @@ this.connections = value;
 if (this.connections[0] >= 0 && this.connections[0] < this.ms.ac) this.currentMesh.connectedAtoms = this.connections;
  else this.connections = this.currentMesh.connectedAtoms = null;
 }return;
-}if ("cutoffRange" === propertyName) {
-this.cutoffRange = value;
-return;
 }if ("fixLattice" === propertyName) {
 if (this.thisMesh != null) this.thisMesh.fixLattice ();
 return;
@@ -361,6 +358,8 @@ this.withinPoints = o[3];
 if (this.withinPoints.size () == 0) this.withinPoints = this.ms.getAtomPointVector (o[2]);
 } else if (("nci" === propertyName || "orbital" === propertyName) && this.sg != null) {
 this.sg.params.testFlags = (this.vwr.getBoolean (603979962) ? 2 : 0);
+} else if ("cutoffRange" === propertyName) {
+this.cutoffRange = value;
 }if (this.sg != null && this.sg.setProp (propertyName, value, bs)) {
 if (this.sg.isValid) {
 if ("molecularOrbital" === propertyName) {
@@ -551,8 +550,10 @@ if (property === "message") {
 var s = "";
 if (!this.jvxlData.isValid) return "invalid! (no atoms selected?)";
 if (!Float.isNaN (this.jvxlData.integration)) s += "integration " + this.jvxlData.integration;
-if (this.shapeID == 24 || this.shapeID == 27 || this.shapeID == 28) s += " with cutoff=" + this.jvxlData.cutoff;
-if (this.shapeID == 27 || this.shapeID == 28) return s;
+if (this.shapeID == 24 || this.shapeID == 27 || this.shapeID == 28) {
+if (this.jvxlData.cutoffRange == null) s += " with cutoff=" + this.jvxlData.cutoff;
+ else s += " with cutoffRange=" + JU.Escape.eAF (this.jvxlData.cutoffRange);
+}if (this.shapeID == 27 || this.shapeID == 28) return s;
 if (this.jvxlData.dataMin != 3.4028235E38) s += " min=" + this.jvxlData.dataMin + " max=" + this.jvxlData.dataMax;
 s += "; " + JV.JC.shapeClassBases[this.shapeID].toLowerCase () + " count: " + this.getPropMC ("count", index);
 return s + this.getPropI ("dataRangeStr", index) + this.jvxlData.msg;
@@ -574,6 +575,7 @@ if (m == null) return null;
 if (property === "output") {
 return (m.jvxlData.sbOut == null && m.jvxlData.jvxlFileTitle == null ? null : m.jvxlData.jvxlFileTitle + "\n" + (m.jvxlData.sbOut == null ? "" : m.jvxlData.sbOut.toString ()));
 }if (property === "cutoff") return Float.$valueOf (this.jvxlData.cutoff);
+if (property === "cutoffRange") return this.jvxlData.cutoffRange;
 if (property === "minMaxInfo") return  Clazz.newFloatArray (-1, [this.jvxlData.dataMin, this.jvxlData.dataMax]);
 if (property === "plane") return this.jvxlData.jvxlPlane;
 if (property === "contours") return m.getContours ();
