@@ -959,8 +959,11 @@ var x =  new JU.V3 ();
 var hAtoms =  new Array (this.ac);
 var bsDeleted = this.vwr.slm.bsDeleted;
 var pt;
-var nH = 0;
-if (bs != null) for (var i = bs.nextSetBit (0); i >= 0; i = bs.nextSetBit (i + 1)) {
+var nH = nTotal[0] = 0;
+if (bs == null) {
+return hAtoms;
+}var nAtoms = bs.cardinality ();
+for (var i = bs.nextSetBit (0); i >= 0; i = bs.nextSetBit (i + 1)) {
 if (bsDeleted != null && bsDeleted.get (i)) continue;
 var atom = this.at[i];
 var atomicNumber = atom.getElementNumber ();
@@ -1016,17 +1019,17 @@ switch (n) {
 default:
 break;
 case 3:
-this.getHybridizationAndAxes (i, atomicNumber, z, x, "sp3b", false, true, isQuick);
+this.getHybridizationAndAxes (i, atomicNumber, z, x, "sp3b", false, true, isQuick, null);
 pt =  new JU.P3 ();
 pt.scaleAdd2 (dHX, z, atom);
 hAtoms[i][hPt++] = pt;
 if (vConnect != null) vConnect.addLast (atom);
-this.getHybridizationAndAxes (i, atomicNumber, z, x, "sp3c", false, true, isQuick);
+this.getHybridizationAndAxes (i, atomicNumber, z, x, "sp3c", false, true, isQuick, null);
 pt =  new JU.P3 ();
 pt.scaleAdd2 (dHX, z, atom);
 hAtoms[i][hPt++] = pt;
 if (vConnect != null) vConnect.addLast (atom);
-this.getHybridizationAndAxes (i, atomicNumber, z, x, "sp3d", false, true, isQuick);
+this.getHybridizationAndAxes (i, atomicNumber, z, x, "sp3d", false, true, isQuick, null);
 pt =  new JU.P3 ();
 pt.scaleAdd2 (dHX, z, atom);
 hAtoms[i][hPt++] = pt;
@@ -1034,12 +1037,12 @@ if (vConnect != null) vConnect.addLast (atom);
 break;
 case 2:
 var isEne = (hybridization == 2 || atomicNumber == 5 || nBonds == 1 && targetValence == 4 || atomicNumber == 7 && this.isAdjacentSp2 (atom));
-this.getHybridizationAndAxes (i, atomicNumber, z, x, (isEne ? "sp2b" : targetValence == 3 ? "sp3c" : "lpa"), false, true, isQuick);
+this.getHybridizationAndAxes (i, atomicNumber, z, x, (isEne ? "sp2b" : targetValence == 3 ? "sp3c" : "lpa"), false, true, isQuick, null);
 pt = JU.P3.newP (z);
 pt.scaleAdd2 (dHX, z, atom);
 hAtoms[i][hPt++] = pt;
 if (vConnect != null) vConnect.addLast (atom);
-this.getHybridizationAndAxes (i, atomicNumber, z, x, (isEne ? "sp2c" : targetValence == 3 ? "sp3d" : "lpb"), false, true, isQuick);
+this.getHybridizationAndAxes (i, atomicNumber, z, x, (isEne ? "sp2c" : targetValence == 3 ? "sp3d" : "lpb"), false, true, isQuick, null);
 pt = JU.P3.newP (z);
 pt.scaleAdd2 (dHX, z, atom);
 hAtoms[i][hPt++] = pt;
@@ -1051,7 +1054,7 @@ case 1:
 if (atomicNumber == 8 && atom === atom.group.getCarbonylOxygenAtom ()) {
 hAtoms[i] = null;
 continue;
-}if (this.getHybridizationAndAxes (i, atomicNumber, z, x, (hybridization == 2 || atomicNumber == 5 || atomicNumber == 6 && this.aaRet[1] == 1 || atomicNumber == 7 && ( new Boolean ( new Boolean (atom.group.getNitrogenAtom () === atom & atom.getFormalCharge () == 0).valueOf () || this.isAdjacentSp2 (atom)).valueOf ()) ? "sp2c" : "sp3d"), true, false, isQuick) != null) {
+}if (this.getHybridizationAndAxes (i, atomicNumber, z, x, (hybridization == 2 || atomicNumber == 5 || atomicNumber == 6 && this.aaRet[1] == 1 || atomicNumber == 7 && ( new Boolean ( new Boolean (atom.group.getNitrogenAtom () === atom & atom.getFormalCharge () == 0).valueOf () || this.isAdjacentSp2 (atom)).valueOf ()) ? "sp2c" : "sp3d"), true, false, isQuick, null) != null) {
 pt = JU.P3.newP (z);
 pt.scaleAdd2 (dHX, z, atom);
 hAtoms[i][hPt++] = pt;
@@ -1060,14 +1063,14 @@ if (vConnect != null) vConnect.addLast (atom);
 hAtoms[i] =  new Array (0);
 }break;
 case 2:
-this.getHybridizationAndAxes (i, atomicNumber, z, x, (targetValence == 4 ? "sp2c" : "sp2b"), false, false, isQuick);
+this.getHybridizationAndAxes (i, atomicNumber, z, x, (targetValence == 4 ? "sp2c" : "sp2b"), false, false, isQuick, null);
 pt = JU.P3.newP (z);
 pt.scaleAdd2 (dHX, z, atom);
 hAtoms[i][hPt++] = pt;
 if (vConnect != null) vConnect.addLast (atom);
 break;
 case 3:
-this.getHybridizationAndAxes (i, atomicNumber, z, x, "spb", false, true, isQuick);
+this.getHybridizationAndAxes (i, atomicNumber, z, x, "spb", false, true, isQuick, null);
 pt = JU.P3.newP (z);
 pt.scaleAdd2 (dHX, z, atom);
 hAtoms[i][hPt++] = pt;
@@ -1135,7 +1138,7 @@ n++;
 return n;
 }, "JU.BS");
 Clazz.defineMethod (c$, "getHybridizationAndAxes", 
-function (atomIndex, atomicNumber, z, x, lcaoTypeRaw, hybridizationCompatible, doAlignZ, isQuick) {
+function (atomIndex, atomicNumber, z, x, lcaoTypeRaw, hybridizationCompatible, doAlignZ, isQuick, ref) {
 var lcaoType = (lcaoTypeRaw.length > 0 && lcaoTypeRaw.charAt (0) == '-' ? lcaoTypeRaw.substring (1) : lcaoTypeRaw);
 if (lcaoTypeRaw.indexOf ("d") >= 0 && !lcaoTypeRaw.endsWith ("sp3d")) return this.getHybridizationAndAxesD (atomIndex, z, x, lcaoType);
 var atom = this.at[atomIndex];
@@ -1276,9 +1279,26 @@ x.normalize ();
 x.cross (vTemp, z);
 break;
 }vTemp.cross (x, z);
-switch (attached[0].getCovalentBondCount ()) {
+var na = attached[0].getCovalentBondCount ();
+switch (na) {
+case 3:
+if (ref !== attached[0]) {
+this.getHybridizationAndAxes (attached[0].i, 0, x, vTemp, "pz", false, doAlignZ, isQuick, atom);
+vTemp.setT (x);
+if (isSp2) {
+x.cross (x, z);
+if (pt == 1) x.scale (-1);
+x.scale (JM.AtomCollection.sqrt3_2);
+z.scaleAdd2 (0.5, z, x);
+} else if (isSp) {
+} else {
+vTemp.setT (z);
+z.setT (x);
+}x.cross (vTemp, z);
+break;
+}na = 2;
 case 1:
-if (attached[0].getValence () != 2) {
+if (na == 1 && attached[0].getValence () != 2) {
 break;
 }case 2:
 var isCumulated = false;
@@ -1316,20 +1336,6 @@ vTemp.setT (x);
 z.setT (x);
 x.cross (JM.AtomCollection.vRef, x);
 }break;
-case 3:
-this.getHybridizationAndAxes (attached[0].i, 0, x, vTemp, "pz", false, doAlignZ, isQuick);
-vTemp.setT (x);
-if (isSp2) {
-x.cross (x, z);
-if (pt == 1) x.scale (-1);
-x.scale (JM.AtomCollection.sqrt3_2);
-z.scaleAdd2 (0.5, z, x);
-} else if (isSp) {
-} else {
-vTemp.setT (z);
-z.setT (x);
-}x.cross (vTemp, z);
-break;
 }
 break;
 case 2:
@@ -1339,7 +1345,7 @@ var a = attached[0];
 var ok = (a.getCovalentBondCount () == 3);
 if (!ok) ok = ((a = attached[1]).getCovalentBondCount () == 3);
 if (ok) {
-this.getHybridizationAndAxes (a.i, 0, x, z, "pz", false, doAlignZ, isQuick);
+this.getHybridizationAndAxes (a.i, 0, x, z, "pz", false, doAlignZ, isQuick, null);
 if (lcaoType.equals ("px")) x.scale (-1);
 z.setT (v[0]);
 break;
@@ -1380,7 +1386,7 @@ x.scale (-1);
 x.normalize ();
 z.normalize ();
 return hybridization;
-}, "~N,~N,JU.V3,JU.V3,~S,~B,~B,~B");
+}, "~N,~N,JU.V3,JU.V3,~S,~B,~B,~B,JU.T3");
 Clazz.defineMethod (c$, "getHybridizationAndAxesD", 
  function (atomIndex, z, x, lcaoType) {
 if (lcaoType.startsWith ("sp3d2")) lcaoType = "d2sp3" + (lcaoType.length == 5 ? "a" : lcaoType.substring (5));
