@@ -147,7 +147,7 @@ Clazz.defineMethod (c$, "compile0",
 this.haveENDIF = false;
 this.script = this.cleanScriptComments (this.script);
 this.ichToken = this.script.indexOf ("# Jmol state version ");
-this.isStateScript = (this.ichToken >= 0);
+this.isStateScript = (this.ichToken == 0);
 if (this.isStateScript) {
 this.ptSemi = this.script.indexOf (";", this.ichToken);
 if (this.ptSemi >= this.ichToken) JS.ScriptManager.setStateScriptVersion (this.vwr, this.script.substring (this.ichToken + "# Jmol state version ".length, this.ptSemi).trim ());
