@@ -57,6 +57,10 @@ Clazz.overrideMethod (c$, "openFileAsyncSpecial",
 function (fileName, flags) {
 this.viewer.openFileAsyncSpecial (fileName, flags);
 }, "~S,~N");
+Clazz.overrideMethod (c$, "openFileAsyncSpecialType", 
+function (fileName, flags, type) {
+this.viewer.openFileAsyncSpecialType (fileName, flags, type);
+}, "~S,~N,~S");
 Clazz.overrideMethod (c$, "processTwoPointGesture", 
 function (touches) {
 this.viewer.processTwoPointGesture (touches);
