@@ -297,7 +297,7 @@ Clazz.defineMethod (c$, "getCEState",
 var n = 0;
 for (var entry, $entry = p.schemes.entrySet ().iterator (); $entry.hasNext () && ((entry = $entry.next ()) || true);) {
 var name = entry.getKey ();
-if ( new Boolean (name.length > 0 & n++ >= 0).valueOf ()) s.append ("color \"" + name + "=" + JU.ColorEncoder.getColorSchemeList (entry.getValue ()) + "\";\n");
+if (name.length > 0 && !name.startsWith ("=") && n++ >= 0) s.append ("color \"" + name + "=" + JU.ColorEncoder.getColorSchemeList (entry.getValue ()) + "\";\n");
 }
 return n;
 }, "JU.ColorEncoder,JU.SB");
@@ -838,9 +838,11 @@ default:
 sb.append ("  set echo ").append (JV.JC.getEchoName (t.valign)).append (" ").append (JV.JC.getHorizAlignmentName (t.align));
 }
 if (t.movableZPercent != 2147483647) sb.append (";  ").append (echoCmd).append (" depth ").appendI (t.movableZPercent);
-if (isImage) sb.append ("; ").append (echoCmd).append (" IMAGE /*file*/");
- else sb.append ("; echo ");
-sb.append (JU.PT.esc (text));
+if (isImage) {
+sb.append ("; ").append (echoCmd).append (" IMAGE /*file*/");
+} else {
+sb.append ("; echo ");
+}sb.append (JU.PT.esc (text));
 sb.append (";\n");
 if (isImage && t.imageScale != 1) sb.append ("  ").append (echoCmd).append (" scale ").appendF (t.imageScale).append (";\n");
 if (t.script != null) sb.append ("  ").append (echoCmd).append (" script ").append (JU.PT.esc (t.script)).append (";\n");
@@ -858,9 +860,10 @@ sb.append ("; color echo background ");
 if (JU.C.isColixTranslucent (t.bgcolix)) sb.append (JU.C.getColixTranslucencyLabel (t.bgcolix)).append (" ");
 sb.append (JU.C.getHexCode (t.bgcolix));
 }sb.append (";\n");
-if (t.hidden) sb.append ("  set echo ID ").append (JU.PT.esc (t.target)).append (" hidden;\n");
-return;
-}, "JU.SB,JM.Text");
+if (t.hidden) {
+if (isScale) sb.append ("  set echo \"%SCALE\" hidden;\n");
+ else sb.append ("  set echo ID ").append (JU.PT.esc (t.target)).append (" hidden;\n");
+}}, "JU.SB,JM.Text");
 Clazz.overrideMethod (c$, "getAllSettings", 
 function (prefix) {
 var g = this.vwr.g;
